/**
 * Value must match the given template
 * @param template Template to base the comparison on
 */
export declare function like(template: any): {
    "pact:matcher:type": string;
    value: any;
};
/**
 * Array where each element must match the given template
 * @param template Template to base the comparison on
 */
export declare function eachLike(template: any): {
    "pact:matcher:type": string;
    value: any[];
};
/**
 * An array that has to have at least one element and each element must match the given template
 * @param template Template to base the comparison on
 * @param count Number of examples to generate, defaults to one
 */
export declare function atLeastOneLike(template: any, count?: number): {
    min: number;
    "pact:matcher:type": string;
    value: any[];
};
/**
 * An array that has to have at least the required number of elements and each element must match the given template
 * @param template Template to base the comparison on
 * @param min Minimum number of elements required in the array
 * @param count Number of examples to generate, defaults to one
 */
export declare function atLeastLike(template: any, min: number, count?: number): {
    min: number;
    "pact:matcher:type": string;
    value: any[];
};
/**
 * An array that has to have at most the required number of elements and each element must match the given template
 * @param template Template to base the comparison on
 * @param max Maximum number of elements required in the array
 * @param count Number of examples to generate, defaults to one
 */
export declare function atMostLike(template: any, max: number, count?: number): {
    max: number;
    "pact:matcher:type": string;
    value: any[];
};
/**
 * An array whose size is constrained to the minimum and maximum number of elements and each element must match the given template
 * @param template Template to base the comparison on
 * @param min Minimum number of elements required in the array
 * @param max Maximum number of elements required in the array
 * @param count Number of examples to generate, defaults to one
 */
export declare function constrainedArrayLike(template: any, min: number, max: number, count?: number): {
    min: number;
    max: number;
    "pact:matcher:type": string;
    value: any[];
};
/**
 * Value must be a boolean
 * @param b Boolean example value
 */
export declare function boolean(b: boolean): {
    "pact:matcher:type": string;
    value: boolean;
};
/**
 * Value must be an integer (must be a number and have no decimal places)
 * @param int Example value. If omitted a random value will be generated.
 */
export declare function integer(int?: number): {
    "pact:matcher:type": string;
    value: number;
    "pact:generator:type"?: undefined;
} | {
    "pact:generator:type": string;
    "pact:matcher:type": string;
    value: number;
};
/**
 * Value must be a decimal number (must be a number and have decimal places)
 * @param num Example value. If omitted a random value will be generated.
 */
export declare function decimal(num?: number): {
    "pact:matcher:type": string;
    value: number;
    "pact:generator:type"?: undefined;
} | {
    "pact:generator:type": string;
    "pact:matcher:type": string;
    value: number;
};
/**
 * Value must be a number
 * @param num Example value. If omitted a random integer value will be generated.
 */
export declare function number(num?: number): {
    "pact:matcher:type": string;
    value: number;
    "pact:generator:type"?: undefined;
} | {
    "pact:generator:type": string;
    "pact:matcher:type": string;
    value: number;
};
/**
 * Value must be a string
 * @param str Example value
 */
export declare function string(str: string): {
    "pact:matcher:type": string;
    value: string;
};
/**
 * Value that must match the given regular expression
 * @param pattern Regular Expression to match
 * @param str Example value
 */
export declare function regex(pattern: string, str: string): {
    "pact:matcher:type": string;
    regex: string;
    value: string;
};
/**
 * Value that must be equal to the example. This is mainly used to reset the matching rules which cascade.
 * @param value Example value
 */
export declare function equal(value: any): {
    "pact:matcher:type": string;
    value: any;
};
/**
 * String value that must match the provided datetime format string.
 * @param format Datetime format string. See [Java SimpleDateFormat](https://docs.oracle.com/javase/8/docs/api/java/text/SimpleDateFormat.html)
 * @param example Example value to use. If omitted a value using the current system date and time will be generated.
 */
export declare function timestamp(format: string, example?: string): {
    "pact:generator:type": string;
    "pact:matcher:type": string;
    timestamp: string;
    value: any;
};
/**
 * String value that must match the provided time format string.
 * @param format Time format string. See [Java SimpleDateFormat](https://docs.oracle.com/javase/8/docs/api/java/text/SimpleDateFormat.html)
 * @param example Example value to use. If omitted a value using the current system time will be generated.
 */
export declare function time(format: string, example?: string): {
    "pact:generator:type": string;
    "pact:matcher:type": string;
    time: string;
    value: any;
};
/**
 * String value that must match the provided date format string.
 * @param format Date format string. See [Java SimpleDateFormat](https://docs.oracle.com/javase/8/docs/api/java/text/SimpleDateFormat.html)
 * @param example Example value to use. If omitted a value using the current system date will be generated.
 */
export declare function date(format: any, example?: string): {
    date: any;
    "pact:generator:type": string;
    "pact:matcher:type": string;
    value: any;
};
/**
 * Value that must include the example value as a substring.
 * @param value String value to include
 */
export declare function includes(value: string): {
    "pact:matcher:type": string;
    value: string;
};
/**
 * Value that must be null. This will only match the JSON Null value. For other content types, it will
 * match if the attribute is missing.
 */
export declare function nullValue(): {
    "pact:matcher:type": string;
};
